essentieel-3

Schrijf zelf de `CREATE`-instructie om een tabel `Kunstwerken` aan te maken. Een kunstwerk heeft een auteur (voorgesteld als maximum 100 tekens tekst), een titel (voorgesteld als maximum 100 tekens tekst) en een waarde (voorgesteld als kommagetal). Gebruik hoofdletters voor je kolomnamen en voer je code uit wanneer je klaar bent om ze te testen. Controleer de output van je script. Indien de instructie mis loopt, lees dan de foutmelding en probeer het probleem op te lossen. Sla je uiteindelijke script op onder MySQL/Essentieel/CreateKunstwerken.sql.